import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Form, Row, Col, Input, Tooltip, Icon, InputNumber, Select, Checkbox, notification, Radio } from 'antd'

import StyleInput from '@/menu/stylecontroller/styleInput'
import './index.scss'

class SettingForm extends Component {
  static propTpyes = {
    dict: PropTypes.object,      // 字典项
    wrap: PropTypes.object,      // 数据源配置
    inputSubmit: PropTypes.func  // 回车事件
  }

  state = {
    msgTemps: [],
    appMenus: [],
    link: this.props.wrap.link || 'menu'
  }

  UNSAFE_componentWillMount () {
    let msgTemps = sessionStorage.getItem('msgTemplate')

    if (msgTemps) {
      try {
        msgTemps = JSON.parse(msgTemps)
      } catch (e) {
        msgTemps = []
      }
    } else {
      msgTemps = []
    }

    let appMenus = sessionStorage.getItem('appMenus')
    if (appMenus) {
      try {
        appMenus = JSON.parse(appMenus)
      } catch (e) {
        appMenus = []
      }
    } else {
      appMenus = []
    }

    this.setState({msgTemps, appMenus})
  }

  handleConfirm = () => {
    // 表单提交时检查输入值是否正确
    return new Promise((resolve, reject) => {
      this.props.form.validateFieldsAndScroll((err, values) => {
        if (!err) {
          if (values.loginWays.includes('sms_vcode') && !values.tempId) {
            notification.warning({
              top: 92,
              message: '使用短信验证码登录时，需要选择短信模板！',
              duration: 5
            })
            return
          }
          resolve(values)
        } else {
          reject(err)
        }
      })
    })
  }

  handleSubmit = (e) => {
    e.preventDefault()

    if (this.props.inputSubmit) {
      this.props.inputSubmit()
    }
  }

  render() {
    const { wrap } = this.props
    const { getFieldDecorator } = this.props.form
    const { msgTemps, appMenus, link } = this.state

    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      }
    }

    return (
      <div className="model-menu-setting-form">
        <Form {...formItemLayout}>
          <Row gutter={24}>
            <Col span={12}>
              <Form.Item label={
                <Tooltip placement="topLeft" title="用于组件间的区分。">
                  <Icon type="question-circle" />
                  组件名称
                </Tooltip>
              }>
                {getFieldDecorator('name', {
                  initialValue: wrap.name,
                  rules: [
                    {
                      required: true,
                      message: this.props.dict['form.required.input'] + '组件名称!'
                    }
                  ]
                })(<Input placeholder={''} autoComplete="off" onPressEnter={this.handleSubmit} />)}
              </Form.Item>
            </Col>
            <Col span={12}>
              <Form.Item label="登录方式">
                {getFieldDecorator('loginWays', {
                  initialValue: wrap.loginWays || [],
                  rules: [
                    {
                      required: true,
                      message: this.props.dict['form.required.select'] + '登录方式!'
                    }
                  ]
                })(
                  <Checkbox.Group
                    options={[
                      { label: '账号', value: 'uname_pwd' },
                      { label: '短信', value: 'sms_vcode' },
                      { label: '扫码', value: 'app_scan' },
                    ]}
                  />
                )}
              </Form.Item>
            </Col>
            <Col span={12}>
              <Form.Item label={
                <Tooltip placement="topLeft" title="栅格布局，每行等分为24列。">
                  <Icon type="question-circle" />
                  宽度
                </Tooltip>
              }>
                {getFieldDecorator('width', {
                  initialValue: wrap.width || 24,
                  rules: [
                    {
                      required: true,
                      message: this.props.dict['form.required.input'] + '宽度!'
                    }
                  ]
                })(<InputNumber min={1} max={24} precision={0} onPressEnter={this.handleSubmit} />)}
              </Form.Item>
            </Col>
            <Col span={12}>
              <Form.Item label={
                <Tooltip placement="topLeft" title="登录框的最大宽度值。">
                  <Icon type="question-circle" />
                  最大宽度
                </Tooltip>
              }>
                {getFieldDecorator('maxWidth', {
                  initialValue: wrap.maxWidth || ''
                })(<InputNumber min={100} max={2000} precision={0} onPressEnter={this.handleSubmit} />)}
              </Form.Item>
            </Col>
            <Col span={12}>
              <Form.Item label={
                <Tooltip placement="topLeft" title="组件占用的最小高度，用于页面布局。">
                  <Icon type="question-circle" />
                  高度
                </Tooltip>
              }>
                {getFieldDecorator('height', {
                  initialValue: wrap.height
                })(<StyleInput options={['px', 'vh', 'vw', '%']}/>)}
              </Form.Item>
            </Col>
            <Col span={12}>
              <Form.Item label="链接">
                {getFieldDecorator('link', {
                  initialValue: wrap.link || 'menu'
                })(
                  <Radio.Group onChange={(e) => this.setState({link: e.target.value})}>
                    <Radio key="menu" value="menu"> 菜单 </Radio>
                    <Radio key="linkmenu" value="linkmenu"> 关联菜单 </Radio>
                  </Radio.Group>
                )}
              </Form.Item>
            </Col>
            {link === 'linkmenu' ? <Col span={12}>
              <Form.Item label="关联菜单">
                {getFieldDecorator('linkmenu', {
                  initialValue: wrap.linkmenu || '',
                  rules: [
                    {
                      required: true,
                      message: this.props.dict['form.required.select'] + '菜单!'
                    }
                  ]
                })(
                  <Select
                    showSearch
                    filterOption={(input, option) => option.props.children.toLowerCase().indexOf(input.toLowerCase()) >= 0}
                  >
                    {appMenus.map(option =>
                      <Select.Option key={option.MenuID} value={option.MenuID}>{option.MenuName}</Select.Option>
                    )}
                  </Select>
                )}
              </Form.Item>
            </Col> : null}
            {/* $验证码$  $mob$  $send_type$ */}
            <Col span={12}>
              <Form.Item label={
                <Tooltip placement="topLeft" title="短信模板可在管理系统 HS-奇云短信模板 处添加。">
                  <Icon type="question-circle" />
                  短信模板
                </Tooltip>
              }>
                {getFieldDecorator('tempId', {
                  initialValue: wrap.tempId || ''
                })(
                  <Select
                    showSearch
                    allowClear
                    filterOption={(input, option) => option.props.children.toLowerCase().indexOf(input.toLowerCase()) >= 0}
                  >
                    {msgTemps.map(option =>
                      <Select.Option key={option.ID} value={option.ID}>{option.SignName + ' - ' + option.TemplateCode}</Select.Option>
                    )}
                  </Select>
                )}
              </Form.Item>
            </Col>
          </Row>
        </Form>
      </div>
    )
  }
}

export default Form.create()(SettingForm)